@@ -131,7 +131,7 @@ equityHist=[]
 datesHist=[]
 def getCurrTime(ops):
     assets=ops['assets']
-    bars=b3.getBars(assets[0],1,b3.INTRADAY)
+    bars=b3.getBars(assets[0],1,timeFrame=b3.INTRADAY)
     return bars['time'][0]
     
 def startOps(ops): 
@@ -142,7 +142,7 @@ def startOps(ops):
     sim_dates.append(getCurrTime(ops))
     mem=ops['mem']
     for asset in assets:
-        dbar=b3.getBars(asset,mem,b3.INTRADAY)
+        dbar=b3.getBars(asset,mem,timeFrame=b3.INTRADAY)
         if not dbar is None and not dbar.empty:
             dbars[asset]=dbar
         else:
@@ -208,7 +208,7 @@ def getCurrBars(ops,dbars):
     for asset in assets:
         dbar=dbars[asset]
         #pega nova barra    
-        aux=b3.getBars(asset,1,b3.INTRADAY) # pega uma barra!
+        aux=b3.getBars(asset,1,timeFrame=b3.INTRADAY) # pega uma barra!
         if not aux is None and not aux.empty:
             dbar=dbar.iloc[1:,] #remove barra mais antiga
             #adiciona nova barra
@@ -220,7 +220,7 @@ def getCurrBars(ops,dbars):
 
 def getLastTime(ops):
     assets=ops['assets']
-    bars=b3.getBars(assets[0],1,b3.INTRADAY)
+    bars=b3.getBars(assets[0],1,timeFrame=b3.INTRADAY)
     return bars['time'][0]
    
 
